package org.hardknockjava.lesson24.exercise01;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.text.DecimalFormat;
import java.text.MessageFormat;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

public class Buildings {
    private static final Locale[] LOCALE_ARRAY //
            = { Locale.GERMANY, Locale.FRANCE, Locale.US };

    private static final Messages MESSAGE_PROVIDER = Messages.getInstance(LOCALE_ARRAY);

    private static final String BUILDING_MESSAGE_PATTERN = "building.data";

    public static void main(String[] args) throws Exception {
        Buildings buildings = new Buildings();
        buildings.process();
    }

    private void process() throws Exception {
        // Create a SimpleDateFormat and NumberFormat to parse
        // the incoming completion date and cost.
        SimpleDateFormat dateFormat = new SimpleDateFormat("MM/dd/yyyy");
        NumberFormat currencyFormat = DecimalFormat.getInstance();

        File inputFile = new File("data/buildings.txt");
        BufferedReader rdr = new BufferedReader(new FileReader(inputFile));

        String line = null;
        while ((line = rdr.readLine()) != null) {
            String[] fields = line.split(",");

            // Populate name, completion date, and cost.
            String name = fields[0];
            String completionDateStr = fields[1];
            Date completionDate = dateFormat.parse(completionDateStr);
            Number cost = currencyFormat.parse(fields[2]);

            // For each of our Locales, fetch the pattern from the
            // ResourceBuilder and format the outgoing message according
            // to the Locale.
            for (Locale locale : LOCALE_ARRAY) {
                String pattern = MESSAGE_PROVIDER.getString(BUILDING_MESSAGE_PATTERN, locale);
                MessageFormat fmt = new MessageFormat(pattern, locale);
                Object[] arguments = { name, completionDate, cost };
                // outputText will be replaced by the formatted message.
                String outputText = fmt.format(arguments);
                System.out.println(outputText);
            }
            System.out.println();
        }
        rdr.close();
    }
}
